Index: trunk/psModules/src/objects/pmSource.c
===================================================================
--- trunk/psModules/src/objects/pmSource.c	(revision 21352)
+++ trunk/psModules/src/objects/pmSource.c	(revision 21363)
@@ -6,6 +6,6 @@
  *  @author EAM, IfA: significant modifications.
  *
- *  @version $Revision: 1.68 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2009-02-06 01:09:50 $
+ *  @version $Revision: 1.69 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2009-02-06 02:31:25 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -44,5 +44,5 @@
     psFree(tmp->peak);
     psFree(tmp->pixels);
-    psFree(tmp->weight);
+    psFree(tmp->variance);
     psFree(tmp->maskObj);
     psFree(tmp->maskView);
@@ -66,5 +66,5 @@
 
     psFree (source->pixels);
-    psFree (source->weight);
+    psFree (source->variance);
     psFree (source->maskObj);
     psFree (source->maskView);
@@ -73,5 +73,5 @@
 
     source->pixels = NULL;
-    source->weight = NULL;
+    source->variance = NULL;
     source->maskObj = NULL;
     source->maskView = NULL;
@@ -101,5 +101,5 @@
     source->peak = NULL;
     source->pixels = NULL;
-    source->weight = NULL;
+    source->variance = NULL;
     source->maskObj = NULL;
     source->maskView = NULL;
@@ -144,5 +144,5 @@
     }
     // this copy is used to allow multiple fit attempts on the
     // same object.  the pixels, weight, and mask arrays all point to
     // the same original subarrays.  the peak and moments point at
     // the original values.
@@ -167,5 +167,5 @@
     // We want a new view, but pointing at the same pixels.
     source->pixels   = psImageCopyView(NULL, in->pixels);
-    source->weight   = psImageCopyView(NULL, in->weight);
+    source->variance   = psImageCopyView(NULL, in->variance);
     source->maskView = in->maskView ? psImageCopyView(NULL, in->maskView) : NULL;
 
@@ -199,6 +199,6 @@
     // these images are subset images of the equivalent parents
     mySource->pixels = psImageSubset(readout->image, srcRegion);
-    if (readout->weight) {
-        mySource->weight = psImageSubset(readout->weight, srcRegion);
+    if (readout->variance) {
+        mySource->variance = psImageSubset(readout->variance, srcRegion);
     }
     if (readout->mask) {
@@ -237,5 +237,5 @@
 
     extend |= (mySource->pixels == NULL);
-    extend |= (mySource->weight == NULL);
+    extend |= (mySource->variance == NULL);
     extend |= (mySource->maskObj == NULL);
     extend |= (mySource->maskView == NULL);
@@ -245,9 +245,9 @@
         // re-create the subimage
         psFree (mySource->pixels);
-        psFree (mySource->weight);
+        psFree (mySource->variance);
         psFree (mySource->maskView);
 
         mySource->pixels   = psImageSubset(readout->image,  newRegion);
-        mySource->weight   = psImageSubset(readout->weight, newRegion);
+        mySource->variance   = psImageSubset(readout->variance, newRegion);
         mySource->maskView = psImageSubset(readout->mask,   newRegion);
         mySource->region   = newRegion;
@@ -670,5 +670,5 @@
     pmSource->peak
     pmSource->pixels
-    pmSource->weight
+    pmSource->variance
     pmSource->mask
 
@@ -737,5 +737,5 @@
 
         psF32 *vPix = source->pixels->data.F32[row];
-        psF32 *vWgt = source->weight->data.F32[row];
+        psF32 *vWgt = source->variance->data.F32[row];
         psImageMaskType *vMsk = (source->maskObj == NULL) ? NULL : source->maskObj->data.PS_TYPE_IMAGE_MASK_DATA[row];
 
@@ -924,5 +924,5 @@
         if (mode & PM_MODEL_OP_NOISE) {
             // XXX need to scale by the gain...
-            target = source->weight->data.F32;
+            target = source->variance->data.F32;
         }
 
@@ -946,5 +946,5 @@
     psImage *target = source->pixels;
     if (mode & PM_MODEL_OP_NOISE) {
-        target = source->weight;
+        target = source->variance;
     }
 
@@ -144,5 +144,5 @@
     }
     // this copy is used to allow multiple fit attempts on the
-    // same object.  the pixels, weight, and mask arrays all point to
+    // same object.  the pixels, variance, and mask arrays all point to
     // the same original subarrays.  the peak and moments point at
     // the original values.
